@@ -105,6 +105,7 @@ class Quota(BASE, ManilaBase):
     project_id = Column(String(255), index=True)
 
     resource = Column(String(255))
+
     hard_limit = Column(Integer, nullable=True)
 
 
@@ -118,6 +119,19 @@ class ProjectUserQuota(BASE, ManilaBase):
     user_id = Column(String(255), nullable=False)
 
     resource = Column(String(255), nullable=False)
+
+    hard_limit = Column(Integer)
+
+
+class ProjectShareTypeQuota(BASE, ManilaBase):
+    """Represents a single quota override for a share type within a project."""
+
+    __tablename__ = 'project_share_type_quotas'
+    id = Column(Integer, primary_key=True, nullable=False)
+    project_id = Column(String(255), nullable=False)
+    share_type_id = Column(
+        String(36), ForeignKey('share_types.id'), nullable=False)
+    resource = Column(String(255), nullable=False)
     hard_limit = Column(Integer)
 
 
@@ -146,6 +160,7 @@ class QuotaUsage(BASE, ManilaBase):
 
     project_id = Column(String(255), index=True)
     user_id = Column(String(255))
+    share_type_id = Column(String(36))
     resource = Column(String(255))
 
     in_use = Column(Integer)
@@ -169,17 +184,12 @@ class Reservation(BASE, ManilaBase):
 
     project_id = Column(String(255), index=True)
     user_id = Column(String(255))
+    share_type_id = Column(String(36))
     resource = Column(String(255))
 
     delta = Column(Integer)
     expire = Column(DateTime, nullable=False)
 
-#    usage = orm.relationship(
-#        "QuotaUsage",
-#        foreign_keys=usage_id,
-#        primaryjoin='and_(Reservation.usage_id == QuotaUsage.id,'
-#                         'QuotaUsage.deleted == 0)')
-
 
 class Share(BASE, ManilaBase):
     """Represents an NFS and CIFS shares."""
@@ -697,18 +707,6 @@ class ShareSnapshot(BASE, ManilaBase):
                              'ShareSnapshot.share_id == Share.id,'
                              'ShareSnapshot.deleted == "False")')
 
-    instances = orm.relationship(
-        "ShareSnapshotInstance",
-        lazy='immediate',
-        primaryjoin=(
-            'and_('
-            'ShareSnapshot.id == ShareSnapshotInstance.snapshot_id, '
-            'ShareSnapshotInstance.deleted == "False")'
-        ),
-        viewonly=True,
-        join_depth=2,
-    )
-
 
 class ShareSnapshotInstance(BASE, ManilaBase):
     """Represents a snapshot of a share."""
@@ -731,21 +729,17 @@ class ShareSnapshotInstance(BASE, ManilaBase):
 
     id = Column(String(36), primary_key=True)
     deleted = Column(String(36), default='False')
-    snapshot_id = Column(
-        String(36), ForeignKey('share_snapshots.id'), nullable=False)
+    snapshot_id = Column(String(36), nullable=True)
     share_instance_id = Column(
         String(36), ForeignKey('share_instances.id'), nullable=False)
     status = Column(String(255))
     progress = Column(String(255))
     provider_location = Column(String(255))
-    share_instance = orm.relationship(
-        ShareInstance, backref="snapshot_instances",
-        lazy='immediate',
-        primaryjoin=(
-            'and_('
-            'ShareSnapshotInstance.share_instance_id == ShareInstance.id,'
-            'ShareSnapshotInstance.deleted == "False")')
-    )
+    share_proto = Column(String(255))
+    size = Column(Integer)
+    share_group_snapshot_id = Column(String(36), nullable=True)
+    user_id = Column(String(255))
+    project_id = Column(String(255))
 
     export_locations = orm.relationship(
         "ShareSnapshotInstanceExportLocation",
@@ -757,6 +751,37 @@ class ShareSnapshotInstance(BASE, ManilaBase):
             'ShareSnapshotInstanceExportLocation.deleted == "False")'
         )
     )
+    share_instance = orm.relationship(
+        ShareInstance, backref="snapshot_instances",
+        lazy='immediate',
+        primaryjoin=(
+            'and_('
+            'ShareSnapshotInstance.share_instance_id == ShareInstance.id,'
+            'ShareSnapshotInstance.deleted == "False")')
+    )
+    snapshot = orm.relationship(
+        "ShareSnapshot",
+        lazy="immediate",
+        foreign_keys=snapshot_id,
+        backref="instances",
+        primaryjoin=(
+            'and_('
+            'ShareSnapshot.id == ShareSnapshotInstance.snapshot_id, '
+            'ShareSnapshotInstance.deleted == "False")'
+        ),
+        viewonly=True,
+        join_depth=2,
+    )
+    share_group_snapshot = orm.relationship(
+        "ShareGroupSnapshot",
+        lazy="immediate",
+        foreign_keys=share_group_snapshot_id,
+        backref="share_group_snapshot_members",
+        primaryjoin=('ShareGroupSnapshot.id == '
+                     'ShareSnapshotInstance.share_group_snapshot_id'),
+        viewonly=True,
+        join_depth=2,
+    )
 
 
 class ShareSnapshotAccessMapping(BASE, ManilaBase):
@@ -1014,6 +1039,9 @@ class ShareGroupTypes(BASE, ManilaBase):
 class ShareGroup(BASE, ManilaBase):
     """Represents a share group."""
     __tablename__ = 'share_groups'
+    _extra_keys = [
+        'availability_zone',
+    ]
     id = Column(String(36), primary_key=True)
     user_id = Column(String(255), nullable=False)
     project_id = Column(String(255), nullable=False)
@@ -1029,7 +1057,10 @@ class ShareGroup(BASE, ManilaBase):
         String(36), ForeignKey('share_servers.id'), nullable=True)
     share_group_type_id = Column(
         String(36), ForeignKey('share_group_types.id'), nullable=True)
+    availability_zone_id = Column(
+        String(36), ForeignKey('availability_zones.id'), nullable=True)
     consistent_snapshot_support = Column(Enum('pool', 'host'), default=None)
+
     share_group_type = orm.relationship(
         ShareGroupTypes,
         backref="share_groups",
@@ -1038,6 +1069,19 @@ class ShareGroup(BASE, ManilaBase):
                     'ShareGroup.share_group_type_id == '
                     'ShareGroupTypes.id,'
                     'ShareGroup.deleted == 0)')
+    _availability_zone = orm.relationship(
+        "AvailabilityZone",
+        lazy='immediate',
+        foreign_keys=availability_zone_id,
+        primaryjoin=(
+            "and_("
+            "ShareGroup.availability_zone_id == AvailabilityZone.id, "
+            "AvailabilityZone.deleted == 'False')"))
+
+    @property
+    def availability_zone(self):
+        if self._availability_zone:
+            return self._availability_zone['name']
 
 
 class ShareGroupTypeProjects(BASE, ManilaBase):
@@ -1140,38 +1184,30 @@ class ShareGroupShareTypeMapping(BASE, ManilaBase):
                      'ShareGroupShareTypeMapping.deleted == "False")')
     )
 
-# TODO(vponomaryov): add 'share_group_snapshot_member_export_locations' model
-# to support mountable share group snapshots and add its relationship to
-# 'share_group_snapshot_members' table.
 
+class Message(BASE, ManilaBase):
+    """Represents a user message.
 
-class ShareGroupSnapshotMember(BASE, ManilaBase):
-    """Represents the share snapshots in a share group snapshot."""
-    __tablename__ = 'share_group_snapshot_members'
-    id = Column(String(36), primary_key=True)
-    # TODO(vponomaryov): make 'share_group_snapshot_id' not nullable.
-    share_group_snapshot_id = Column(
-        String(36), ForeignKey('share_group_snapshots.id'))
-    share_id = Column(String(36), ForeignKey('shares.id'))
-    # TODO(vponomaryov): make 'share_instance_id' not nullable.
-    share_instance_id = Column(String(36), ForeignKey('share_instances.id'))
-    size = Column(Integer)
-    status = Column(String(255))
-    share_proto = Column(String(255))
-    user_id = Column(String(255))
-    project_id = Column(String(255))
+    User messages show information about API operations to the API end-user.
+    """
+    __tablename__ = 'messages'
+    id = Column(String(36), primary_key=True, nullable=False)
+    project_id = Column(String(255), nullable=False)
+    # Info/Error/Warning.
+    message_level = Column(String(255), nullable=False)
+    request_id = Column(String(255), nullable=True)
+    resource_type = Column(String(255))
+    # The uuid of the related resource.
+    resource_id = Column(String(36), nullable=True)
+    # Operation specific action ID, this ID is mapped
+    # to a message in manila/message/message_field.py
+    action_id = Column(String(10), nullable=False)
+    # After this time the message may no longer exist.
+    expires_at = Column(DateTime, nullable=True)
+    # Message detail ID, this ID is mapped
+    # to a message in manila/message/message_field.py
+    detail_id = Column(String(10), nullable=True)
     deleted = Column(String(36), default='False')
-    provider_location = Column(String(255))
-    # TODO(vponomaryov): add relationship to source share instance as it is
-    # done for share snapshot instances.
-    # TODO(vponomaryov): add share group snapshot member export locations
-    # relationship.
-    share_group_snapshot = orm.relationship(
-        ShareGroupSnapshot,
-        backref="share_group_snapshot_members",
-        foreign_keys=share_group_snapshot_id,
-        primaryjoin='ShareGroupSnapshot.id == '
-                    'ShareGroupSnapshotMember.share_group_snapshot_id')
 
 
 def register_models():
